@@ -134,6 +134,7 @@ sub test_002 {
     my ( $test, $test_dir, $rules ) = construct_tests;
 
     $test->samples( [ 'Sample_01', 'Sample_02' ] );
+    $test->global_attr->samples( [ 'Sample_01', 'Sample_02' ] );
 
     # $test->stdout(1);
     $test->set_rule_names;
@@ -143,23 +144,16 @@ sub test_002 {
         _init_rule( $test, $rule );
     }
 
-    diag Dumper( $test->global_attr->some_list );
-    diag Dumper( $test->global_attr->use_somes );
-    diag Dumper( $test->global_attr->some );
+    ok(-d 'data/processed/Sample_01', 'Sample Dir exists');
+    ok(-d 'data/processed/Sample_02', 'Sample Dir exists');
+
+    # diag Dumper( $test->global_attr->some_list );
+    # diag Dumper( $test->global_attr->use_somes );
+    # diag Dumper( $test->global_attr->some );
     ok(1);
 
 }
 
-sub create_times {
-    my $now = DateTime->now( time_zone => 'local' );
-    my $strp = DateTime::Format::Strptime->new(
-        pattern   => '%a %b %e %T %Y',
-        time_zone => 'local',
-    );
-
-    return $now, $strp;
-}
-
 sub _init_rule {
     my $test = shift;
     my $rule = shift;
